==> cordova-plugin-humanapi-1.0.1.tgz: package/src/android/human/HumanAPIProperties.java <==
package com.github.vikramezhil.cordova.human;

/**
 * HumanAPI Properties
 * 
 * @author Vikram Ezhil
 */

public class HumanAPIProperties {
    // https://reference.humanapi.co/v2.1/reference#activities
    public static final String ACTIVITIES_URL = "https://api.humanapi.co/v1/human/activities";

    // https://reference.humanapi.co/v2.1/reference#activity-summaries
    public static final String ACTIVITIES_SUMMARIES_URL = "https://api.humanapi.co/v1/human/activities/summaries";

    // https://reference.humanapi.co/v2.1/reference#blood-glucose
    public static final String BLOOD_GLUCOSE_URL = "https://api.humanapi.co/v1/human/blood_glucose";

    // https://reference.humanapi.co/v2.1/reference#blood-oxygen
    public static final String BLOOD_OXYGEN_URL = "https://api.humanapi.co/v1/human/blood_oxygen";

    // https://reference.humanapi.co/v2.1/reference#blood-pressure
    public static final String BLOOD_PRESSURE_URL = "https://api.humanapi.co/v1/human/blood_pressure";

    // https://reference.humanapi.co/v2.1/reference#body-mass-index-bmi
    public static final String BMI_URL = "https://api.humanapi.co/v1/human/bmi";

    // https://reference.humanapi.co/v2.1/reference#body-fat
    public static final String BODY_FAT_URL = "https://api.humanapi.co/v1/human/body_fat";

    // https://reference.humanapi.co/v2.1/reference#heart-rate
    public static final String HEART_RATE_URL = "https://api.humanapi.co/v1/human/heart_rate";

    // https://reference.humanapi.co/v2.1/reference#heart-rate-summaries
    public static final String HEART_RATE_SUMMARIES_URL = "https://api.humanapi.co/v1/human/heart_rate/summaries";

    // https://reference.humanapi.co/v2.1/reference#height
    public static final String HEIGHT_URL = "https://api.humanapi.co/v1/human/height";

    // https://reference.humanapi.co/v2.1/reference#weight
    public static final String WEIGHT_URL = "https://api.humanapi.co/v1/human/weight";

    // https://reference.humanapi.co/v2.1/reference#locations
    public static final String LOCATIONS_URL = "https://api.humanapi.co/v1/human/locations";

    // https://reference.humanapi.co/v2.1/reference#meals
    public static final String MEALS_URL = "https://api.humanapi.co/v1/human/food/meals";

    // https://reference.humanapi.co/v2.1/reference#sleeps
    public static final String SLEEPS_URL = "https://api.humanapi.co/v1/human/sleeps";

    // https://reference.humanapi.co/v2.1/reference#sleep-summaries
    public static final String SLEEP_SUMMARIES_URL = "https://api.humanapi.co/v1/human/sleeps/summaries";

    // https://reference.humanapi.co/v2.1/reference#human-summary
    public static final String HUMAN_SUMMARY_URL = "https://api.humanapi.co/v1/human";

    // https://reference.humanapi.co/v2.1/reference#profile-1
    public static final String HUMAN_PROFILE_URL = "https://api.humanapi.co/v1/human/profile";
}

==> cordova-plugin-humanapi-1.0.3.tgz: package/src/android/human/HumanAPIProperties.java <==
package com.github.vikramezhil.cordova.human;

/**
 * HumanAPI Properties
 * 
 * @author Vikram Ezhil
 */

public class HumanAPIProperties {
    // https://reference.humanapi.co/v2.1/reference#activities
    public static final String ACTIVITIES_URL = "https://api.humanapi.co/v1/human/activities";

    // https://reference.humanapi.co/v2.1/reference#activity-summaries
    public static final String ACTIVITIES_SUMMARIES_URL = "https://api.humanapi.co/v1/human/activities/summaries";

    // https://reference.humanapi.co/v2.1/reference#blood-glucose
    public static final String BLOOD_GLUCOSE_URL = "https://api.humanapi.co/v1/human/blood_glucose/readings";

    // https://reference.humanapi.co/v2.1/reference#blood-oxygen
    public static final String BLOOD_OXYGEN_URL = "https://api.humanapi.co/v1/human/blood_oxygen/readings";

    // https://reference.humanapi.co/v2.1/reference#blood-pressure
    public static final String BLOOD_PRESSURE_URL = "https://api.humanapi.co/v1/human/blood_pressure/readings";

    // https://reference.humanapi.co/v2.1/reference#body-mass-index-bmi
    public static final String BMI_URL = "https://api.humanapi.co/v1/human/bmi/readings";

    // https://reference.humanapi.co/v2.1/reference#body-fat
    public static final String BODY_FAT_URL = "https://api.humanapi.co/v1/human/body_fat/readings";

    // https://reference.humanapi.co/v2.1/reference#heart-rate
    public static final String HEART_RATE_URL = "https://api.humanapi.co/v1/human/heart_rate/readings";

    // https://reference.humanapi.co/v2.1/reference#heart-rate-summaries
    public static final String HEART_RATE_SUMMARIES_URL = "https://api.humanapi.co/v1/human/heart_rate/summaries";

    // https://reference.humanapi.co/v2.1/reference#height
    public static final String HEIGHT_URL = "https://api.humanapi.co/v1/human/height/readings";

    // https://reference.humanapi.co/v2.1/reference#weight
    public static final String WEIGHT_URL = "https://api.humanapi.co/v1/human/weight/readings";

    // https://reference.humanapi.co/v2.1/reference#locations
    public static final String LOCATIONS_URL = "https://api.humanapi.co/v1/human/locations";

    // https://reference.humanapi.co/v2.1/reference#meals
    public static final String MEALS_URL = "https://api.humanapi.co/v1/human/food/meals";

    // https://reference.humanapi.co/v2.1/reference#sleeps
    public static final String SLEEPS_URL = "https://api.humanapi.co/v1/human/sleeps";

    // https://reference.humanapi.co/v2.1/reference#sleep-summaries
    public static final String SLEEP_SUMMARIES_URL = "https://api.humanapi.co/v1/human/sleeps/summaries";

    // https://reference.humanapi.co/v2.1/reference#human-summary
    public static final String HUMAN_SUMMARY_URL = "https://api.humanapi.co/v1/human";

    // https://reference.humanapi.co/v2.1/reference#profile-1
    public static final String HUMAN_PROFILE_URL = "https://api.humanapi.co/v1/human/profile";

    // https://reference.humanapi.co/v2.1/reference#sources
    public static final String HUMAN_SOURCE_URL = "https://api.humanapi.co/v1/human/sources";
}
